==> linpsk_0.6.2.orig.tar.gz: linpsk-0.6.2/linpsk/constants.h <==
/***************************************************************************
                          constants.h  -  description
                             -------------------
    begin                : Fri Apr 21 2000
    copyright            : (C) 2000 by Volker Schroer
    email                : DL1KSV@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *   based on the work of Moe Wheatley, AE4JY                              *
 ***************************************************************************/

#ifndef CONSTANTS_H
#define CONSTANTS_H

#include <math.h>						// for some constants like PI
#define TXOFF_CODE -1			// control codes that can be placed in the input
#define TXON_CODE -2			// queue for various control functions
#define TXTOG_CODE -3

#define FFT_SIZE 2048
#define FFT_SAMPLERATEX2 11025	// 2 x the fft sample rate(so is an integer)

#define TXBUFFER_LENGTH 1000
#define BUF_SIZE 4096	//size of data chunks to process at a time from
											// the soundcard

// define some constants
#define PI2 ( M_PI + M_PI )		// 2 Pi
//#define PHZ_180_MIN	(M_PI_4)		//Pi/4
#define PHZ_180_MIN  ( 0.0 )
//#define PHZ_180_MAX	(3.0*PI2/8.0)	//3Pi/4
#define PHZ_180_MAX ( M_PI )
//#define PHZ_0_MIN	(5.0*PI2/8.0)	//5Pi/4
#define PHZ_0_MIN ( M_PI )
//#define PHZ_0_MAX	(7.0*PI2/8.0)	//7Pi/4
#define PHZ_0_MAX ( PI2 )
#define Ts (.032+.000000)			// Ts == symbol period(correct for +/- .23%error)
#define M_PI_3_2	(M_PI_2+M_PI)		// 3Pi/2
#define M_PI_3_4  (M_PI_2+M_PI_4) // 3Pi/4
#define M_PI_5_4	(M_PI + M_PI_4) // 5Pi/4
#define M_PI_7_4	(M_PI + M_PI_2 + M_PI_4) // 7Pi/4
// Coefficents for AFC- Filtering
#define a1coeff 1.8
#define a2coeff -1.8
#endif

==> linpsk_0.7.1-1.tar.gz: linpsk-0.7.1/linpsk/constants.h <==
/***************************************************************************
                          constants.h  -  description
                             -------------------
    begin                : Fri Apr 21 2000
    copyright            : (C) 2000 by Volker Schroer
    email                : DL1KSV@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *   based on the work of Moe Wheatley, AE4JY                              *
 ***************************************************************************/

#ifndef CONSTANTS_H
#define CONSTANTS_H

#include <math.h>						// for some constants like PI
//#include <qstring.h>

#define TXOFF_CODE -1			// control codes that can be placed in the input
#define TXON_CODE -2			// queue for various control functions
#define TXTOG_CODE -3

#define FFT_SIZE 2048
#define FFT_SAMPLERATEX2 11025	// 2 x the fft sample rate(so is an integer)

#define TXBUFFER_LENGTH 1000
#define BUF_SIZE 4096	//size of data chunks to process at a time from
											// the soundcard
#define RxWindowBuffer 50 // Max Number of Lines in the RX ScrollBuffer

// define some constants
#define PI2 ( M_PI + M_PI )		// 2 Pi

#define Ts (.032+.000000)			// Ts == symbol period(correct for +/- .23%error)
#define M_PI_3_2	(M_PI_2+M_PI)		// 3Pi/2
#define M_PI_3_4  (M_PI_2+M_PI_4) // 3Pi/4
#define M_PI_5_4	(M_PI + M_PI_4) // 5Pi/4
#define M_PI_7_4	(M_PI + M_PI_2 + M_PI_4) // 7Pi/4

enum Mode {BPSK=0,QPSK,RTTY,MFSK16};



// LengtH of Hilber Transformer Coefficients

#define HilbertFilterLength 37
#endif
